==> roughpy-0.0.2a0.tar.gz: roughpy-0.0.2a0/algebra/src/libalgebra_lite_internal/vector_type_helper.h <==
// Copyright (c) 2023 RoughPy Developers. All rights reserved.
//
// Redistribution and use in source and binary forms, with or without modification,
// are permitted provided that the following conditions are met:
//
// 1. Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright notice,
// this list of conditions and the following disclaimer in the documentation
// and/or other materials provided with the distribution.
//
// 3. Neither the name of the copyright holder nor the names of its contributors
// may be used to endorse or promote products derived from this software without
// specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
// USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

//
// Created by user on 07/03/23.
//

#ifndef ROUGHPY_ALGEBRA_SRC_LIBALGEBRA_LITE_VECTOR_TYPE_HELPER_H
#define ROUGHPY_ALGEBRA_SRC_LIBALGEBRA_LITE_VECTOR_TYPE_HELPER_H

#include <roughpy/algebra/algebra_fwd.h>

#include <libalgebra_lite/dense_vector.h>
#include <libalgebra_lite/sparse_vector.h>

namespace rpy {
namespace algebra {
namespace dtl {

template <template <typename, typename> class VT> struct vector_type_helper;

template <> struct vector_type_helper<lal::sparse_vector> {
    static constexpr VectorType vtype = VectorType::Sparse;
};

template <> struct vector_type_helper<lal::dense_vector> {
    static constexpr VectorType vtype = VectorType::Dense;
};

}// namespace dtl
}// namespace algebra
}// namespace rpy

#endif//ROUGHPY_ALGEBRA_SRC_LIBALGEBRA_LITE_VECTOR_TYPE_HELPER_H

==> roughpy-0.0.4.tar.gz: roughpy-0.0.4/algebra/src/libalgebra_lite_internal/vector_type_helper.h <==
// Copyright (c) 2023 RoughPy Developers. All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
// 1. Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright notice,
// this list of conditions and the following disclaimer in the documentation
// and/or other materials provided with the distribution.
//
// 3. Neither the name of the copyright holder nor the names of its contributors
// may be used to endorse or promote products derived from this software without
// specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.

//
// Created by user on 07/03/23.
//

#ifndef ROUGHPY_ALGEBRA_SRC_LIBALGEBRA_LITE_VECTOR_TYPE_HELPER_H
#define ROUGHPY_ALGEBRA_SRC_LIBALGEBRA_LITE_VECTOR_TYPE_HELPER_H

#include <roughpy/algebra/algebra_fwd.h>

#include <libalgebra_lite/dense_vector.h>
#include <libalgebra_lite/sparse_vector.h>

namespace rpy {
namespace algebra {
namespace dtl {

template <template <typename, typename> class VT>
struct vector_type_helper;

template <>
struct vector_type_helper<lal::sparse_vector> {
    static constexpr VectorType vtype = VectorType::Sparse;
};

template <>
struct vector_type_helper<lal::dense_vector> {
    static constexpr VectorType vtype = VectorType::Dense;
};

}// namespace dtl
}// namespace algebra
}// namespace rpy

#endif// ROUGHPY_ALGEBRA_SRC_LIBALGEBRA_LITE_VECTOR_TYPE_HELPER_H
